@@ -7,7 +7,7 @@ from typing import Final, Optional, Tuple
 from pyplumio import util
 from pyplumio.const import ATTR_LAMBDA_SENSOR
 from pyplumio.helpers.typing import DeviceDataType
-from pyplumio.structures import Structure
+from pyplumio.structures import StructureDecoder, make_device_data
 
 LAMBDA_LEVEL: Final = "lambda_level"
 LAMBDA_STATUS: Final = "lambda_status"
@@ -19,20 +19,13 @@ LAMBDA: Tuple[str, ...] = (
 )
 
 
-class LambaSensorStructure(Structure):
+class LambaSensorStructure(StructureDecoder):
     """Represents lambda sensor data structure."""
 
-    def encode(self, data: DeviceDataType) -> bytearray:
-        """Encode device data to bytearray message."""
-        return bytearray()
-
     def decode(
         self, message: bytearray, offset: int = 0, data: Optional[DeviceDataType] = None
     ) -> Tuple[DeviceDataType, int]:
         """Decode bytes and return message data and offset."""
-        if data is None:
-            data = {}
-
         lambda_sensor: DeviceDataType = {}
         if message[offset] != 0xFF:
             lambda_sensor[LAMBDA_STATUS] = message[offset]
@@ -43,7 +36,4 @@ class LambaSensorStructure(Structure):
             )
             offset += 3
 
-        offset += 1
-        data[ATTR_LAMBDA_SENSOR] = lambda_sensor
-
-        return data, offset
+        return make_device_data(data, {ATTR_LAMBDA_SENSOR: lambda_sensor}), offset + 1
